==> qflipclock_1.0.tar.gz: qflipclock-1.0/src/translations/qflipclock_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>QFlipClock_App</name>
    <message>
        <location filename="../qflipclock-standalone.cpp" line="32"/>
        <source>Flip Clock</source>
        <translation>Flip Часы</translation>
    </message>
    <message>
        <location filename="../qflipclock-standalone.cpp" line="48"/>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
</context>
<context>
    <name>QFlipClock_Widget</name>
    <message>
        <location filename="../qflipclock-widget.cpp" line="23"/>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Flip Clock Widget Settings</source>
        <translation type="obsolete">Настройки виджета Flip часов</translation>
    </message>
    <message>
        <location filename="../ui/settings.ui" line="14"/>
        <source>Flip Clock Settings</source>
        <translation>Настройки Flip Часов</translation>
    </message>
    <message>
        <location filename="../ui/settings.ui" line="28"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../ui/settings.ui" line="36"/>
        <source>Theme:</source>
        <translation>Тема:</translation>
    </message>
    <message>
        <location filename="../ui/settings.ui" line="82"/>
        <source>Transition:</source>
        <translation>Переход:</translation>
    </message>
    <message>
        <source>Transition</source>
        <translation type="obsolete">Переход</translation>
    </message>
    <message>
        <location filename="../ui/settings.ui" line="126"/>
        <source>Keep Backlight On</source>
        <translation>Не гасить экран</translation>
    </message>
    <message>
        <location filename="../ui/settings.ui" line="181"/>
        <source>Save</source>
        <translation>Применить</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="24"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="24"/>
        <source>Slide</source>
        <translation>Сдвиг</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="25"/>
        <source>Flip</source>
        <translation>Перекидание</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="25"/>
        <source>Rotate</source>
        <translation>Переворот</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="42"/>
        <source>unnamed</source>
        <translation>без имени</translation>
    </message>
</context>
<context>
    <name>WidgetSettings</name>
    <message>
        <location filename="../ui/widgetsettings.ui" line="14"/>
        <source>Flip Clock Widget Settings</source>
        <translation>Настройки виджета Flip часов</translation>
    </message>
    <message>
        <location filename="../ui/widgetsettings.ui" line="28"/>
        <source>Widget size</source>
        <translation>Размер виджета</translation>
    </message>
    <message>
        <location filename="../ui/widgetsettings.ui" line="42"/>
        <source>240x160</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/widgetsettings.ui" line="64"/>
        <source>400x266</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/widgetsettings.ui" line="83"/>
        <source>500x416</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/widgetsettings.ui" line="102"/>
        <source>Custom...</source>
        <translation>Другой...</translation>
    </message>
    <message>
        <location filename="../ui/widgetsettings.ui" line="163"/>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/widgetsettings.ui" line="209"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../ui/widgetsettings.ui" line="217"/>
        <source>Theme:</source>
        <translation>Тема:</translation>
    </message>
    <message>
        <location filename="../ui/widgetsettings.ui" line="234"/>
        <source>Transition:</source>
        <translation>Переход:</translation>
    </message>
    <message>
        <source>Transition</source>
        <translation type="obsolete">Переход</translation>
    </message>
    <message>
        <location filename="../ui/widgetsettings.ui" line="251"/>
        <source>On click:</source>
        <translation>По нажатию:</translation>
    </message>
    <message>
        <location filename="../ui/widgetsettings.ui" line="298"/>
        <source>Save</source>
        <translation>Применить</translation>
    </message>
    <message>
        <location filename="../widgetsettings.cpp" line="50"/>
        <location filename="../widgetsettings.cpp" line="76"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../widgetsettings.cpp" line="50"/>
        <source>Slide</source>
        <translation>Сдвиг</translation>
    </message>
    <message>
        <location filename="../widgetsettings.cpp" line="51"/>
        <source>Flip</source>
        <translation>Перекидание</translation>
    </message>
    <message>
        <location filename="../widgetsettings.cpp" line="51"/>
        <source>Rotate</source>
        <translation>Переворот</translation>
    </message>
    <message>
        <location filename="../widgetsettings.cpp" line="68"/>
        <source>unnamed</source>
        <translation>без имени</translation>
    </message>
    <message>
        <location filename="../widgetsettings.cpp" line="76"/>
        <source>FlipClock</source>
        <translation>Flip Часы</translation>
    </message>
    <message>
        <location filename="../widgetsettings.cpp" line="77"/>
        <source>Maemo Clock</source>
        <translation>Стандартные Часы</translation>
    </message>
</context>
</TS>

==> qflipclock_1.1.0.tar.gz: qflipclock-1.1.0/src/translations/qflipclock_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>Hour</name>
    <message>
        <source>AM</source>
        <translation>AM</translation>
    </message>
    <message>
        <source>PM</source>
        <translation>PM</translation>
    </message>
</context>
<context>
    <name>QFlipClock_App</name>
    <message>
        <source>Flip Clock</source>
        <translation type="obsolete">Flip Часы</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="obsolete">&amp;Настройки</translation>
    </message>
</context>
<context>
    <name>QFlipClock_Widget</name>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Flip Clock Widget Settings</source>
        <translation type="obsolete">Настройки виджета Flip часов</translation>
    </message>
    <message>
        <source>Flip Clock Settings</source>
        <translation type="obsolete">Настройки Flip Часов</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Настройки</translation>
    </message>
    <message>
        <source>Theme:</source>
        <translation type="obsolete">Тема:</translation>
    </message>
    <message>
        <source>Transition:</source>
        <translation type="obsolete">Переход:</translation>
    </message>
    <message>
        <source>Transition</source>
        <translation type="obsolete">Переход</translation>
    </message>
    <message>
        <source>Keep Backlight On</source>
        <translation type="obsolete">Не гасить экран</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="obsolete">Применить</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Нет</translation>
    </message>
    <message>
        <source>Slide</source>
        <translation type="obsolete">Сдвиг</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation type="obsolete">Перекидание</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="obsolete">Переворот</translation>
    </message>
    <message>
        <source>unnamed</source>
        <translation type="obsolete">без имени</translation>
    </message>
</context>
<context>
    <name>WidgetSettings</name>
    <message>
        <source>Flip Clock Widget Settings</source>
        <translation>Настройки виджета Flip часов</translation>
    </message>
    <message>
        <source>Widget size</source>
        <translation>Размер виджета</translation>
    </message>
    <message>
        <source>Custom...</source>
        <translation>Другой...</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <source>Theme:</source>
        <translation type="obsolete">Тема:</translation>
    </message>
    <message>
        <source>Transition:</source>
        <translation type="obsolete">Переход:</translation>
    </message>
    <message>
        <source>Transition</source>
        <translation>Переход</translation>
    </message>
    <message>
        <source>On click:</source>
        <translation type="obsolete">По нажатию:</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Применить</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <source>Slide</source>
        <translation>Сдвиг</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Перекидание</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Переворот</translation>
    </message>
    <message>
        <source>unnamed</source>
        <translation>без имени</translation>
    </message>
    <message>
        <source>FlipClock</source>
        <translation>Flip Часы</translation>
    </message>
    <message>
        <source>Maemo Clock</source>
        <translation>Стандартные Часы</translation>
    </message>
    <message>
        <source>Show Background</source>
        <translation>Показывать фон</translation>
    </message>
    <message>
        <source>Add Zero sign</source>
        <translation>Добавлять ноль</translation>
    </message>
    <message>
        <source>Transitions</source>
        <translation type="obsolete">Переход</translation>
    </message>
    <message>
        <source>200</source>
        <translation></translation>
    </message>
    <message>
        <source>300</source>
        <translation></translation>
    </message>
    <message>
        <source>400</source>
        <translation></translation>
    </message>
    <message>
        <source>500</source>
        <translation></translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
    <message>
        <source>On-Click</source>
        <translation>По нажатию</translation>
    </message>
</context>
</TS>
